# Changelog

All notable changes to this project will be documented in this file.
## [0.2.8](https://github.com/satyaborg/blurt/releases/tag/v0.2.8) — 2026-02-14

### Bug fixes

- fix global esc ([1b81b94](https://github.com/satyaborg/blurt/commit/1b81b949fe158cededbf54a2baea3f01489e429d))
- fix clipboard ([d879107](https://github.com/satyaborg/blurt/commit/d87910708366c7ff9b97932e58e0e46b8d2fb841))
- fix truncation ([25d8453](https://github.com/satyaborg/blurt/commit/25d8453bf135240fe9ff7076bc10dfde0d5a155b))

### Changes

- rename hotkey -> shortcut ([b43e791](https://github.com/satyaborg/blurt/commit/b43e791bb2dc32abed0adcf5c4e9ca0e1f90a62e))

### Features

- add rich table view -log ([5712fb5](https://github.com/satyaborg/blurt/commit/5712fb5285b347335381009b61c30b23c6953f14))
## [0.2.7](https://github.com/satyaborg/blurt/releases/tag/v0.2.7) — 2026-02-13

### Changes

- mod toml ([cfb8e3a](https://github.com/satyaborg/blurt/commit/cfb8e3a412e9c8d7c4552a70108a9c51553e4c0e))
## [0.2.6](https://github.com/satyaborg/blurt/releases/tag/v0.2.6) — 2026-02-13

### Changes

- mod path ([c6b6e39](https://github.com/satyaborg/blurt/commit/c6b6e39cc05105f3e9b1f2e0cdb43d8c08e1da7a))
## [0.2.4](https://github.com/satyaborg/blurt/releases/tag/v0.2.4) — 2026-02-13

### Features

- add gif ([275f19a](https://github.com/satyaborg/blurt/commit/275f19a8514c2c08b783ede76edbd77fd07db0b0))
## [0.2.3](https://github.com/satyaborg/blurt/releases/tag/v0.2.3) — 2026-02-13

### Features

- add demo ([5de2898](https://github.com/satyaborg/blurt/commit/5de2898998c6f8d3ea15a282f6408fa4919a2ccf))
## [0.2.2](https://github.com/satyaborg/blurt/releases/tag/v0.2.2) — 2026-02-13

### Features

- add upgrade command ([39d4e4b](https://github.com/satyaborg/blurt/commit/39d4e4ba2f9b79bfd56eb938682c077b1d162092))
## [0.2.1](https://github.com/satyaborg/blurt/releases/tag/v0.2.1) — 2026-02-13

### Changes

- update readme ([a3d057a](https://github.com/satyaborg/blurt/commit/a3d057a1da2b9865e03057a0d508e615f01735b1))
## [0.2.0](https://github.com/satyaborg/blurt/releases/tag/v0.2.0) — 2026-02-13

### Bug fixes

- fix docstrings ([b58605f](https://github.com/satyaborg/blurt/commit/b58605f1bd4a08bbe2f7487d762f4f4be5f58207))

### Changes

- bump version ([49e8f9d](https://github.com/satyaborg/blurt/commit/49e8f9d54b0385bfdcad1bff5fbf0491dab71627))
- remove brew ([1f8f438](https://github.com/satyaborg/blurt/commit/1f8f43846cb3f006af677c8717b6b7b6765294d3))

### Features

- add pypi release workflow ([4ec51dd](https://github.com/satyaborg/blurt/commit/4ec51ddf1dd54cf30fddb3245d96cfa0eb0237c1))

### Other

- initial commit ([3d8f2ec](https://github.com/satyaborg/blurt/commit/3d8f2ec487c85207d9bd2335b1d5615933c3e3ed))
